@@ -72,6 +72,7 @@ class ServerDeployer(RegionedDeployer):
         self.server_attrs = None
         self.phases = [
                 (True, self.find_existing),
+                (lambda: self.server_attrs, self.wait_for_running),
                 (lambda: not self.server_attrs, self.create),
                 (True, self.add_to_inventory),
                 ]
@@ -99,6 +100,13 @@ class ServerDeployer(RegionedDeployer):
                 break
             instances.append(i)
 
+    def wait_for_running(self):
+        """Waits for found servers to be operational"""
+        self.server_attrs = self.consul.find_running(
+                self.server_attrs,
+                self.launch_timeout_s,
+                )
+
     def create(self):
         """Launches a new server instance."""
         self.server_attrs = self.consul.create_server(
@@ -122,6 +130,71 @@ class ServerDeployer(RegionedDeployer):
             self.stack.add_host(addy, self.groups, self.hostvars)
 
 
+class CloudManagerServerDeployer(ServerDeployer):
+    """
+    Server deployer for cloud management services.
+
+    Cloud management services like RightScale and Scalr provide constructs like
+    server templates (a.k.a. roles) to bundle together disk image ids with
+    on-server configuration automation (e.g. RightScripts, Scalr scripts).
+    This deployer replaces the low-level provisioning functionality in the base
+    :class:`ServerDeployer` with a :meth:`create` method that is more suited to
+    the high-level launching mechanism provided by cloud management services.
+    """
+    def __init__(self, *args, **kwargs):
+        super(CloudManagerServerDeployer, self).__init__(*args, **kwargs)
+        self.server_def = None
+        self.phases = [
+                (True, self.create_stack),
+                (True, self.find_existing),
+                (lambda: self.server_attrs, self.wait_for_running),
+                (lambda: not self.server_attrs, self.find_def),
+                (lambda: not (self.server_attrs or self.server_def),
+                    self.define),
+                (lambda: not self.server_attrs, self.create),
+                (True, self.add_to_inventory),
+                ]
+
+    def create_stack(self):
+        self.consul.create_stack(self.stack.name)
+
+    def find_def(self):
+        server_defs = self.consul.find_server_defs(self.name)
+        maxnames = len(server_defs)
+        while server_defs:
+            href = server_defs.pop(0)
+            if self.namespace.add_if_unique(href):
+                log.info('Found existing server def, %s' % href)
+                self.server_def = href
+                break
+            if len(self.namespace.names) >= maxnames:
+                break
+            server_defs.append(href)
+
+    def define(self):
+        """Defines a new server."""
+        self.server_def = self.consul.define_server(
+                self.name,
+                self.server_tpl,
+                self.server_tpl_rev,
+                self.instance_type,
+                self.ssh_key_name,
+                tags=self.tags,
+                availability_zone=self.availability_zone,
+                security_groups=self.security_groups,
+                )
+        log.debug('Defined server %s' % self.server_def)
+
+    def create(self):
+        self.server_attrs = self.consul.create_server(
+                self.server_def,
+                self.inputs,
+                timeout_s=self.launch_timeout_s,
+                )
+        log.debug('Post launch delay: %d s' % self.post_launch_delay_s)
+        time.sleep(self.post_launch_delay_s)
+
+
 class SecurityGroupDeployer(RegionedDeployer):
     def __init__(self, *args, **kwargs):
         super(SecurityGroupDeployer, self).__init__(*args, **kwargs)
@@ -316,14 +389,16 @@ class LoadBalancerDeployer(RegionedDeployer):
     def configure_nodes(self):
         """Ensure that the LB's nodes matches the stack"""
         # Since load balancing runs after server provisioning,
-        # the servers should already be created regardless of 
+        # the servers should already be created regardless of
         # whether this was a preexisting load balancer or not.
         # We also have the existing nodes, because add_to_inventory
         # has been called already
         required_nodes = self._get_required_nodes()
 
-        log.debug("Matching existing lb nodes to required %s (port %s)" %
-               (", ".join(required_nodes), self.backend_port))
+        log.debug(
+                "Matching existing lb nodes to required %s (port %s)"
+                % (", ".join(required_nodes), self.backend_port)
+                )
 
         self.consul.match_lb_nodes(
             self.lb_attrs[A.loadbalancer.ID],
@@ -331,7 +406,9 @@ class LoadBalancerDeployer(RegionedDeployer):
             required_nodes,
             self.backend_port)
 
-        self.lb_attrs = self.consul.lb_details(self.lb_attrs[A.loadbalancer.ID]) 
+        self.lb_attrs = self.consul.lb_details(
+                self.lb_attrs[A.loadbalancer.ID]
+                )
 
     def _get_required_nodes(self):
         required_nodes = set()
@@ -340,11 +417,12 @@ class LoadBalancerDeployer(RegionedDeployer):
                 required_nodes.add(host)
         return required_nodes
 
-
     def add_to_inventory(self):
         """Adds lb IPs to stack inventory"""
         if self.lb_attrs:
-            self.lb_attrs = self.consul.lb_details(self.lb_attrs[A.loadbalancer.ID])
+            self.lb_attrs = self.consul.lb_details(
+                    self.lb_attrs[A.loadbalancer.ID]
+                    )
             host = self.lb_attrs['virtualIps'][0]['address']
             self.stack.add_lb_secgroup(self.name, [host], self.backend_port)
             self.stack.add_host(
@@ -353,9 +431,11 @@ class LoadBalancerDeployer(RegionedDeployer):
                     self.lb_attrs
                     )
 
+
 class LoadBalancerSecurityGroupsDeployer(SecurityGroupRulesetDeployer):
     def __init__(self, *args, **kwargs):
-        super(LoadBalancerSecurityGroupsDeployer, self).__init__(*args, **kwargs)
+        super(LoadBalancerSecurityGroupsDeployer, self).__init__(
+                *args, **kwargs)
         self.group = None
         self.attrs = {}
 
@@ -363,10 +443,12 @@ class LoadBalancerSecurityGroupsDeployer(SecurityGroupRulesetDeployer):
         # Prepopulate rules from the LB stack variables
         lb_entry = self.stack.lb_sec_groups.dicts.get(self.load_balancer)
         if not lb_entry:
-            raise Exception, \
-                "No load balancer host found in stack for '%s'" % self.load_balancer
+            raise Exception(
+                "No load balancer host found in stack for '%s'"
+                % self.load_balancer
+                )
         for host in lb_entry['hosts']:
-            # Create a rule for this LB. Need a mask or nova interprets it 
+            # Create a rule for this LB. Need a mask or nova interprets it
             # as a group rule rather than IP rule
             host = host + "/32"
             rule = {
@@ -374,12 +456,12 @@ class LoadBalancerSecurityGroupsDeployer(SecurityGroupRulesetDeployer):
                     A.secgroup.FROM: lb_entry['port'],
                     A.secgroup.TO: lb_entry['port'],
                     A.secgroup.SOURCE: host,
-                   }       
+                   }
             self.rules.append(rule)
 
         super(LoadBalancerSecurityGroupsDeployer, self).find_existing()
 
-DEPLOYER_MAP = {
+DEFAULT_DEPLOYER_MAP = {
         R.SSH_KEYS: SSHKeyDeployer,
         R.SERVERS: ServerDeployer,
         R.SERVER_SECURITY_GROUPS: SecurityGroupDeployer,
@@ -390,6 +472,19 @@ DEPLOYER_MAP = {
         R.DYNAMIC_LB_SEC_GROUPS: LoadBalancerSecurityGroupsDeployer,
         }
 
+CLOUD_MANAGER_DEPLOYER_OVERRIDES = {
+        'rightscale': {
+            R.SERVERS: CloudManagerServerDeployer,
+            },
+        }
+
+
+def get_deployer(provider, res_type):
+    deployer = CLOUD_MANAGER_DEPLOYER_OVERRIDES.get(provider, {}).get(res_type)
+    if not deployer:
+        deployer = DEFAULT_DEPLOYER_MAP[res_type]
+    return deployer
+
 
 def get_deployers(res_config, res_type, stack, creds):
     pname = res_config[A.PROVIDER]
@@ -398,6 +493,6 @@ def get_deployers(res_config, res_type, stack, creds):
     if not consul:
         log.warn("%s does not provide %s" % (pname, res_type))
         return
-    deployer = DEPLOYER_MAP[res_type]
+    deployer = get_deployer(pname, res_type)
     count = res_config.get('instance_count', 1)
     return [deployer(stack, res_config, consul) for _ in range(count)]
