@@ -19,11 +19,13 @@ import json
 import multiprocessing
 import os.path
 
-from ansible.callbacks import (
-        AggregateStats,
-        PlaybookCallbacks,
-        PlaybookRunnerCallbacks,
-        )
+# work around circular import in ansible as discussed on ansible-devel:
+#
+#     https://groups.google.com/forum/#!topic/ansible-devel/wE7fNbGyWbo
+#
+import ansible.utils  # noqa
+
+from ansible import callbacks
 from ansible.playbook import PlayBook
 from .deployers import get_stage_deployers
 from .inventory import BangsibleInventory
@@ -257,13 +259,15 @@ class Stack(object):
         if ssh_user:
             pb_kwargs['remote_user'] = ssh_user
 
+        # DEBUG: this is like passing ``-vvvv`` to ansible-playbook
+        # ansible.utils.VERBOSITY = 4
         for playbook in cfg.get(A.PLAYBOOKS, []):
             playbook_path = os.path.join(playbook_dir, playbook)
 
             # gratuitously stolen from main() in ``ansible-playbook``
-            stats = AggregateStats()
-            playbook_cb = PlaybookCallbacks(verbose=1)
-            runner_cb = PlaybookRunnerCallbacks(stats, verbose=1)
+            stats = callbacks.AggregateStats()
+            playbook_cb = callbacks.PlaybookCallbacks(verbose=1)
+            runner_cb = callbacks.PlaybookRunnerCallbacks(stats, verbose=1)
 
             extra_kwargs = {
                     'playbook': playbook_path,
@@ -280,10 +284,12 @@ class Stack(object):
                     }
             pb_kwargs.update(extra_kwargs)
             pb = PlayBook(**pb_kwargs)
-            pb.inventory = BangsibleInventory(
+            inventory = BangsibleInventory(
                     copy.deepcopy(self.groups_and_vars.lists),
                     copy.deepcopy(self.groups_and_vars.dicts),
                     )
+            inventory.set_playbook_basedir(playbook_dir)
+            pb.inventory = inventory
 
             pb.run()
 
